@@ -234,7 +234,7 @@ class WorkerServer(BaseServer):
             d.addCallback(self.createJob, spider_info, uuid)
             d.addErrback(self.workerError)
             return d
-        LOGGER.critical('No spider_info given for uuid %s' % uuid)
+        LOGGER.info('No spider_info given for uuid %s' % uuid)
         self.chan.basic_ack(delivery_tag=delivery_tag)
         return None
     
@@ -246,7 +246,7 @@ class WorkerServer(BaseServer):
             LOGGER.info('Remapping resource %s to %s' % (function_name, self.service_mapping[function_name]))
             function_name = self.service_mapping[function_name]
         job['function_name'] = function_name
-        job['reservation_cache'] = None
+        # job['reservation_cache'] = None
         job['uuid'] = uuid
         job['account'] = account
         # Save account info in memcached for up to 7 days
@@ -264,16 +264,8 @@ class WorkerServer(BaseServer):
         # remap some fields that differ from the plugin and the database
         if service_name in self.service_args_mapping:
             for key in self.service_args_mapping[service_name]:
-                job['account']['%s' % self.service_args_mapping[service_name][key]] = job['account'][key]
-        # if ('%s_user_id' % service_name) in job['account']:
-        #     job['account']['user_id'] = job['account']['%s_user_id' % service_name]
-        #     job['account']['username'] = job['account']['%s_user_id' % service_name]
-        # if 'session_key' in job['account']:
-        #     job['account']['sk'] = job['account']['session_key']
-        # if 'secret' in job['account']:
-        #     job['account']['token_secret'] = job['account']['secret']
-        # if 'key' in job['account']:
-        #     job['account']['token_key'] = job['account']['key']
+                if key in job['account']:
+                    job['account'][self.service_args_mapping[service_name][key]] = job['account'][key]
         # apply job fields to req and optional kwargs
         for arg in job['exposed_function']['required_arguments']:
             if arg in job['account']:
@@ -281,34 +273,9 @@ class WorkerServer(BaseServer):
         for arg in job['exposed_function']['optional_arguments']:
             if arg in job['account']:
                 kwargs[arg] = job['account'][arg]
-        LOGGER.critical(kwargs)
+        LOGGER.debug('Function: %s\nKWARGS: %s' %(job['function_name'], repr(kwargs)))
         return kwargs
         
-    def createReservation(self, function_name, **kwargs):
-        uuid = uuid4().hex
-        if not isinstance(function_name, str):
-            for key in self.functions:
-                if self.functions[key]["function"] == function_name:
-                    function_name = key
-                    break
-        if function_name not in self.functions:
-            raise Exception("Function %s does not exist." % function_name)
-        d = self.callExposedFunction(
-            self.functions[function_name]["function"], 
-            kwargs, 
-            function_name, 
-            uuid=uuid)
-        d.addCallback(self._createReservationCallback, function_name, uuid)
-        d.addErrback(self._createReservationErrback, function_name, uuid)
-        return d
-        
-    def _createReservationCallback(self, data, function_name, uuid):
-        return data
-            
-    def _createReservationErrback(self, error, function_name, uuid):
-        LOGGER.error("Unable to create reservation for %s:%s, %s.\n" % (function_name, uuid, error))
-        return {}
-        
     def getNetworkAddress(self):
         d = getNetworkAddress()
         d.addCallback(self._getNetworkAddressCallback)
